@@ -12,8 +12,9 @@
 #include <string.h>
 
 #include "soup-auth-domain.h"
-#include "soup.h"
+#include "soup-message.h"
 #include "soup-path-map.h"
+#include "soup-uri.h"
 
 /**
  * SECTION:soup-auth-domain
@@ -73,6 +74,11 @@ typedef struct {
 
 G_DEFINE_ABSTRACT_TYPE (SoupAuthDomain, soup_auth_domain, G_TYPE_OBJECT)
 
+static void set_property (GObject *object, guint prop_id,
+			  const GValue *value, GParamSpec *pspec);
+static void get_property (GObject *object, guint prop_id,
+			  GValue *value, GParamSpec *pspec);
+
 static void
 soup_auth_domain_init (SoupAuthDomain *domain)
 {
@@ -82,7 +88,7 @@ soup_auth_domain_init (SoupAuthDomain *domain)
 }
 
 static void
-soup_auth_domain_finalize (GObject *object)
+finalize (GObject *object)
 {
 	SoupAuthDomainPrivate *priv = SOUP_AUTH_DOMAIN_GET_PRIVATE (object);
 
@@ -97,86 +103,6 @@ soup_auth_domain_finalize (GObject *object)
 	G_OBJECT_CLASS (soup_auth_domain_parent_class)->finalize (object);
 }
 
-static void
-soup_auth_domain_set_property (GObject *object, guint prop_id,
-			       const GValue *value, GParamSpec *pspec)
-{
-	SoupAuthDomain *auth_domain = SOUP_AUTH_DOMAIN (object);
-	SoupAuthDomainPrivate *priv = SOUP_AUTH_DOMAIN_GET_PRIVATE (object);
-
-	switch (prop_id) {
-	case PROP_REALM:
-		g_free (priv->realm);
-		priv->realm = g_value_dup_string (value);
-		break;
-	case PROP_PROXY:
-		priv->proxy = g_value_get_boolean (value);
-		break;
-	case PROP_ADD_PATH:
-		soup_auth_domain_add_path (auth_domain,
-					   g_value_get_string (value));
-		break;
-	case PROP_REMOVE_PATH:
-		soup_auth_domain_remove_path (auth_domain,
-					      g_value_get_string (value));
-		break;
-	case PROP_FILTER:
-		priv->filter = g_value_get_pointer (value);
-		break;
-	case PROP_FILTER_DATA:
-		if (priv->filter_dnotify) {
-			priv->filter_dnotify (priv->filter_data);
-			priv->filter_dnotify = NULL;
-		}
-		priv->filter_data = g_value_get_pointer (value);
-		break;
-	case PROP_GENERIC_AUTH_CALLBACK:
-		priv->auth_callback = g_value_get_pointer (value);
-		break;
-	case PROP_GENERIC_AUTH_DATA:
-		if (priv->auth_dnotify) {
-			priv->auth_dnotify (priv->auth_data);
-			priv->auth_dnotify = NULL;
-		}
-		priv->auth_data = g_value_get_pointer (value);
-		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
-static void
-soup_auth_domain_get_property (GObject *object, guint prop_id,
-			       GValue *value, GParamSpec *pspec)
-{
-	SoupAuthDomainPrivate *priv = SOUP_AUTH_DOMAIN_GET_PRIVATE (object);
-
-	switch (prop_id) {
-	case PROP_REALM:
-		g_value_set_string (value, priv->realm);
-		break;
-	case PROP_PROXY:
-		g_value_set_boolean (value, priv->proxy);
-		break;
-	case PROP_FILTER:
-		g_value_set_pointer (value, priv->filter);
-		break;
-	case PROP_FILTER_DATA:
-		g_value_set_pointer (value, priv->filter_data);
-		break;
-	case PROP_GENERIC_AUTH_CALLBACK:
-		g_value_set_pointer (value, priv->auth_callback);
-		break;
-	case PROP_GENERIC_AUTH_DATA:
-		g_value_set_pointer (value, priv->auth_data);
-		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
 static void
 soup_auth_domain_class_init (SoupAuthDomainClass *auth_domain_class)
 {
@@ -184,9 +110,9 @@ soup_auth_domain_class_init (SoupAuthDomainClass *auth_domain_class)
 
 	g_type_class_add_private (auth_domain_class, sizeof (SoupAuthDomainPrivate));
 
-	object_class->finalize = soup_auth_domain_finalize;
-	object_class->set_property = soup_auth_domain_set_property;
-	object_class->get_property = soup_auth_domain_get_property;
+	object_class->finalize = finalize;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
 
 	/**
 	 * SOUP_AUTH_DOMAIN_REALM:
@@ -290,6 +216,86 @@ soup_auth_domain_class_init (SoupAuthDomainClass *auth_domain_class)
 				      G_PARAM_READWRITE));
 }
 
+static void
+set_property (GObject *object, guint prop_id,
+	      const GValue *value, GParamSpec *pspec)
+{
+	SoupAuthDomain *auth_domain = SOUP_AUTH_DOMAIN (object);
+	SoupAuthDomainPrivate *priv = SOUP_AUTH_DOMAIN_GET_PRIVATE (object);
+
+	switch (prop_id) {
+	case PROP_REALM:
+		g_free (priv->realm);
+		priv->realm = g_value_dup_string (value);
+		break;
+	case PROP_PROXY:
+		priv->proxy = g_value_get_boolean (value);
+		break;
+	case PROP_ADD_PATH:
+		soup_auth_domain_add_path (auth_domain,
+					   g_value_get_string (value));
+		break;
+	case PROP_REMOVE_PATH:
+		soup_auth_domain_remove_path (auth_domain,
+					      g_value_get_string (value));
+		break;
+	case PROP_FILTER:
+		priv->filter = g_value_get_pointer (value);
+		break;
+	case PROP_FILTER_DATA:
+		if (priv->filter_dnotify) {
+			priv->filter_dnotify (priv->filter_data);
+			priv->filter_dnotify = NULL;
+		}
+		priv->filter_data = g_value_get_pointer (value);
+		break;
+	case PROP_GENERIC_AUTH_CALLBACK:
+		priv->auth_callback = g_value_get_pointer (value);
+		break;
+	case PROP_GENERIC_AUTH_DATA:
+		if (priv->auth_dnotify) {
+			priv->auth_dnotify (priv->auth_data);
+			priv->auth_dnotify = NULL;
+		}
+		priv->auth_data = g_value_get_pointer (value);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+get_property (GObject *object, guint prop_id,
+	      GValue *value, GParamSpec *pspec)
+{
+	SoupAuthDomainPrivate *priv = SOUP_AUTH_DOMAIN_GET_PRIVATE (object);
+
+	switch (prop_id) {
+	case PROP_REALM:
+		g_value_set_string (value, priv->realm);
+		break;
+	case PROP_PROXY:
+		g_value_set_boolean (value, priv->proxy);
+		break;
+	case PROP_FILTER:
+		g_value_set_pointer (value, priv->filter);
+		break;
+	case PROP_FILTER_DATA:
+		g_value_set_pointer (value, priv->filter_data);
+		break;
+	case PROP_GENERIC_AUTH_CALLBACK:
+		g_value_set_pointer (value, priv->auth_callback);
+		break;
+	case PROP_GENERIC_AUTH_DATA:
+		g_value_set_pointer (value, priv->auth_data);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
 /**
  * soup_auth_domain_add_path:
  * @domain: a #SoupAuthDomain
@@ -572,8 +578,8 @@ soup_auth_domain_covers (SoupAuthDomain *domain, SoupMessage *msg)
  * This is used by #SoupServer internally and is probably of no use to
  * anyone else.
  *
- * Return value: (nullable): the username that @msg has authenticated
- * as, if in fact it has authenticated. %NULL otherwise.
+ * Return value: the username that @msg has authenticated as, if in
+ * fact it has authenticated. %NULL otherwise.
  **/
 char *
 soup_auth_domain_accepts (SoupAuthDomain *domain, SoupMessage *msg)
