@@ -68,7 +68,7 @@ typedef struct {
 	goffset               write_length;
 	goffset               written;
 
-	guint read_tag, write_tag, tls_signal_id;
+	guint read_tag, write_tag;
 	GSource *unpause_source;
 
 	SoupMessageGetHeadersFn   get_headers_cb;
@@ -102,8 +102,6 @@ soup_message_io_cleanup (SoupMessage *msg)
 		return;
 	priv->io_data = NULL;
 
-	if (io->tls_signal_id)
-		g_signal_handler_disconnect (io->sock, io->tls_signal_id);
 	if (io->sock)
 		g_object_unref (io->sock);
 	if (io->item)
@@ -146,8 +144,6 @@ soup_message_io_stop (SoupMessage *msg)
 
 	if (io->read_state < SOUP_MESSAGE_IO_STATE_FINISHING)
 		soup_socket_disconnect (io->sock);
-	else if (io->item && io->item->conn)
-		soup_connection_set_state (io->item->conn, SOUP_CONNECTION_IDLE);
 }
 
 #define SOUP_MESSAGE_IO_EOL            "\r\n"
@@ -1050,25 +1046,6 @@ io_read (SoupSocket *sock, SoupMessage *msg)
 	goto read_more;
 }
 
-static void
-socket_tls_certificate_changed (GObject *sock, GParamSpec *pspec,
-				gpointer msg)
-{
-	GTlsCertificate *certificate;
-	GTlsCertificateFlags errors;
-
-	g_object_get (sock,
-		      SOUP_SOCKET_TLS_CERTIFICATE, &certificate,
-		      SOUP_SOCKET_TLS_ERRORS, &errors,
-		      NULL);
-	g_object_set (msg,
-		      SOUP_MESSAGE_TLS_CERTIFICATE, certificate,
-		      SOUP_MESSAGE_TLS_ERRORS, errors,
-		      NULL);
-	if (certificate)
-		g_object_unref (certificate);
-}
-
 static SoupMessageIOData *
 new_iostate (SoupMessage *msg, SoupSocket *sock, SoupMessageIOMode mode,
 	     SoupMessageGetHeadersFn get_headers_cb,
@@ -1101,8 +1078,24 @@ new_iostate (SoupMessage *msg, SoupSocket *sock, SoupMessageIOMode mode,
 	io->write_state = SOUP_MESSAGE_IO_STATE_NOT_STARTED;
 
 	if (soup_socket_is_ssl (io->sock)) {
-		io->tls_signal_id = g_signal_connect (io->sock, "notify::tls-certificate",
-						      G_CALLBACK (socket_tls_certificate_changed), msg);
+		GTlsCertificate *certificate;
+		GTlsCertificateFlags errors;
+
+		g_object_get (sock,
+			      SOUP_SOCKET_TLS_CERTIFICATE, &certificate,
+			      SOUP_SOCKET_TLS_ERRORS, &errors,
+			      NULL);
+		g_object_set (msg,
+			      SOUP_MESSAGE_TLS_CERTIFICATE, certificate,
+			      SOUP_MESSAGE_TLS_ERRORS, errors,
+			      NULL);
+		if (certificate)
+			g_object_unref (certificate);
+	} else {
+		g_object_set (msg,
+			      SOUP_MESSAGE_TLS_CERTIFICATE, NULL,
+			      SOUP_MESSAGE_TLS_ERRORS, 0,
+			      NULL);
 	}
 
 	if (priv->io_data)
